class Subscription_Access {
  bool? subscriptionAlreadyPurchased;
  List<PurchasedSubscriptions>? purchasedSubscriptions;
  bool? freeTrialConsumed;
  bool? allowRenewal;
  bool? internalUser;
  Payload? payload;
  String? consumptionId;
  String? signature;
  bool? downloadExists;

  Subscription_Access(
      {this.subscriptionAlreadyPurchased,
      this.purchasedSubscriptions,
      this.freeTrialConsumed,
      this.allowRenewal,
      this.internalUser,
      this.payload,
      this.consumptionId,
      this.signature,
      this.downloadExists});

  Subscription_Access.fromJson(Map<String, dynamic> json) {
    subscriptionAlreadyPurchased = json['subscriptionAlreadyPurchased'];
    if (json['purchasedSubscriptions'] != null) {
      purchasedSubscriptions = <PurchasedSubscriptions>[];
      json['purchasedSubscriptions'].forEach((v) {
        purchasedSubscriptions!.add(PurchasedSubscriptions.fromJson(v));
      });
    }
    freeTrialConsumed = json['freeTrialConsumed'];
    allowRenewal = json['allowRenewal'];
    internalUser = json['internalUser'];
    payload =
        json['payload'] != null ? Payload.fromJson(json['payload']) : null;
    consumptionId = json['consumptionId'];
    signature = json['signature'];
    downloadExists = json['downloadExists'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['subscriptionAlreadyPurchased'] = subscriptionAlreadyPurchased;
    if (purchasedSubscriptions != null) {
      data['purchasedSubscriptions'] =
          purchasedSubscriptions!.map((v) => v.toJson()).toList();
    }
    data['freeTrialConsumed'] = freeTrialConsumed;
    data['allowRenewal'] = allowRenewal;
    data['internalUser'] = internalUser;
    if (payload != null) {
      data['payload'] = payload!.toJson();
    }
    data['consumptionId'] = consumptionId;
    data['signature'] = signature;
    data['downloadExists'] = downloadExists;
    return data;
  }
}

class PurchasedSubscriptions {
  String? purchasedDate;
  String? validity;
  PriceDetails? priceDetails;
  List? offerDetails;
  Subscription? subscription;
  SubscriptionDetails? subscriptionDetails;

  PurchasedSubscriptions(
      {this.purchasedDate,
      this.validity,
      this.priceDetails,
      this.offerDetails,
      this.subscription,
      this.subscriptionDetails});

  PurchasedSubscriptions.fromJson(Map<String, dynamic> json) {
    purchasedDate = json['purchasedDate'];
    validity = json['validity'];
    priceDetails = json['priceDetails'] != null
        ? PriceDetails.fromJson(json['priceDetails'])
        : null;
    if (json['offerDetails'] != null) {
      offerDetails = [];
      if (json['offerDetails'] != null) {
        json['offerDetails'].forEach((v) {
          offerDetails!.add(v);
        });
      }
    }
    subscription = json['subscription'] != null
        ? Subscription.fromJson(json['subscription'])
        : null;
    subscriptionDetails = json['subscriptionDetails'] != null
        ? SubscriptionDetails.fromJson(json['subscriptionDetails'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['purchasedDate'] = purchasedDate;
    data['validity'] = validity;
    if (priceDetails != null) {
      data['priceDetails'] = priceDetails!.toJson();
    }
    if (offerDetails != null) {
      data['offerDetails'] = offerDetails!.map((v) => v.toJson()).toList();
    }
    if (subscription != null) {
      data['subscription'] = subscription!.toJson();
    }
    if (subscriptionDetails != null) {
      data['subscriptionDetails'] = subscriptionDetails!.toJson();
    }
    return data;
  }
}

class PriceDetails {
  int? amount;
  String? currency;

  PriceDetails({this.amount, this.currency});

  PriceDetails.fromJson(Map<String, dynamic> json) {
    amount = json['amount'];
    currency = json['currency'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['amount'] = amount;
    data['currency'] = currency;
    return data;
  }
}

class Subscription {
  String? tierId;
  bool? digital;
  bool? physical;
  bool? adFree;
  String? title;
  bool? renew;
  int? duration;
  String? durationText;

  Subscription(
      {this.tierId,
      this.digital,
      this.physical,
      this.adFree,
      this.title,
      this.renew,
      this.duration,
      this.durationText});

  Subscription.fromJson(Map<String, dynamic> json) {
    tierId = json['tierId'];
    digital = json['digital'];
    physical = json['physical'];
    adFree = json['adFree'];
    title = json['title'];
    renew = json['renew'];
    duration = json['duration'];
    durationText = json['durationText'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['tierId'] = tierId;
    data['digital'] = digital;
    data['physical'] = physical;
    data['adFree'] = adFree;
    data['title'] = title;
    data['renew'] = renew;
    data['duration'] = duration;
    data['durationText'] = durationText;
    return data;
  }
}

class SubscriptionDetails {
  FreeTrial? freeTrial;
  String? benefits;
  bool? physical;
  bool? digital;
  bool? adFree;
  bool? migrated;
  bool? couponsEnabled;
  String? adminCoupon;
  List? usedCouponNumbers;
  String? sId;
  bool? recommended;
  bool? enabled;
  String? clientId;
  String? title;
  String? iconUrl;
  List<Tiers>? tiers;
  String? createdAt;
  String? updatedAt;
  int? iV;
  int? couponCount;
  String? currencySymbol;

  SubscriptionDetails(
      {this.freeTrial,
      this.benefits,
      this.physical,
      this.digital,
      this.adFree,
      this.migrated,
      this.couponsEnabled,
      this.adminCoupon,
      this.usedCouponNumbers,
      this.sId,
      this.recommended,
      this.enabled,
      this.clientId,
      this.title,
      this.iconUrl,
      this.tiers,
      this.createdAt,
      this.updatedAt,
      this.iV,
      this.couponCount,
      this.currencySymbol});

  SubscriptionDetails.fromJson(Map<String, dynamic> json) {
    freeTrial = json['freeTrial'] != null
        ? FreeTrial.fromJson(json['freeTrial'])
        : null;
    benefits = json['benefits'];
    physical = json['physical'];
    digital = json['digital'];
    adFree = json['adFree'];
    migrated = json['migrated'];
    couponsEnabled = json['couponsEnabled'];
    adminCoupon = json['adminCoupon'];
    if (json['usedCouponNumbers'] != null) {
      usedCouponNumbers = [];
      if (json['usedCouponNumbers'] != null) {
        json['usedCouponNumbers'].forEach((v) {
          usedCouponNumbers!.add(v);
        });
      }
    }
    sId = json['_id'];
    recommended = json['recommended'];
    enabled = json['enabled'];
    clientId = json['clientId'];
    title = json['title'];
    iconUrl = json['iconUrl'];
    if (json['tiers'] != null) {
      tiers = <Tiers>[];
      json['tiers'].forEach((v) {
        tiers!.add(Tiers.fromJson(v));
      });
    }
    createdAt = json['createdAt'];
    updatedAt = json['updatedAt'];
    iV = json['__v'];
    couponCount = json['couponCount'];
    currencySymbol = json['currencySymbol'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (freeTrial != null) {
      data['freeTrial'] = freeTrial!.toJson();
    }
    data['benefits'] = benefits;
    data['physical'] = physical;
    data['digital'] = digital;
    data['adFree'] = adFree;
    data['migrated'] = migrated;
    data['couponsEnabled'] = couponsEnabled;
    data['adminCoupon'] = adminCoupon;
    if (usedCouponNumbers != null) {
      data['usedCouponNumbers'] =
          usedCouponNumbers!.map((v) => v.toJson()).toList();
    }
    data['_id'] = sId;
    data['recommended'] = recommended;
    data['enabled'] = enabled;
    data['clientId'] = clientId;
    data['title'] = title;
    data['iconUrl'] = iconUrl;
    if (tiers != null) {
      data['tiers'] = tiers!.map((v) => v.toJson()).toList();
    }
    data['createdAt'] = createdAt;
    data['updatedAt'] = updatedAt;
    data['__v'] = iV;
    data['couponCount'] = couponCount;
    data['currencySymbol'] = currencySymbol;
    return data;
  }
}

class FreeTrial {
  bool? enabled;
  int? duration;

  FreeTrial({this.enabled, this.duration});

  FreeTrial.fromJson(Map<String, dynamic> json) {
    enabled = json['enabled'];
    duration = json['duration'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['enabled'] = enabled;
    data['duration'] = duration;
    return data;
  }
}

class Tiers {
  PriceOverrides? priceOverrides;
  String? currency;
  int? basePrice;
  List<Offers>? offers;
  String? sId;
  int? price;
  int? duration;

  Tiers(
      {this.priceOverrides,
      this.currency,
      this.basePrice,
      this.offers,
      this.sId,
      this.price,
      this.duration});

  Tiers.fromJson(Map<String, dynamic> json) {
    priceOverrides = json['priceOverrides'] != null
        ? PriceOverrides.fromJson(json['priceOverrides'])
        : null;
    currency = json['currency'];
    basePrice = json['basePrice'];
    if (json['offers'] != null) {
      offers = <Offers>[];
      json['offers'].forEach((v) {
        offers!.add(Offers.fromJson(v));
      });
    }
    sId = json['_id'];
    price = json['price'];
    duration = json['duration'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (priceOverrides != null) {
      data['priceOverrides'] = priceOverrides!.toJson();
    }
    data['currency'] = currency;
    data['basePrice'] = basePrice;
    if (offers != null) {
      data['offers'] = offers!.map((v) => v.toJson()).toList();
    }
    data['_id'] = sId;
    data['price'] = price;
    data['duration'] = duration;
    return data;
  }
}

class PriceOverrides {
  List? country;

  PriceOverrides({this.country});

  PriceOverrides.fromJson(Map<String, dynamic> json) {
    if (json['country'] != null) {
      country = [];
      if (json['country'] != null) {
        json['country'].forEach((v) {
          country!.add(v);
        });
      }
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.country != null) {
      data['country'] = this.country!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Offers {
  String? sId;
  String? title;
  String? benefits;
  String? iconUrl;

  Offers({this.sId, this.title, this.benefits, this.iconUrl});

  Offers.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    title = json['title'];
    benefits = json['benefits'];
    iconUrl = json['iconUrl'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['_id'] = sId;
    data['title'] = title;
    data['benefits'] = benefits;
    data['iconUrl'] = iconUrl;
    return data;
  }
}

class Payload {
  String? clientId;
  String? subscriptionId;
  String? createdAt;

  Payload({this.clientId, this.subscriptionId, this.createdAt});

  Payload.fromJson(Map<String, dynamic> json) {
    clientId = json['clientId'];
    subscriptionId = json['subscriptionId'];
    createdAt = json['createdAt'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['clientId'] = clientId;
    data['subscriptionId'] = subscriptionId;
    data['createdAt'] = createdAt;
    return data;
  }
}
