import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import '../Model/APIMode.dart';
import 'ConscentInitializer.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewApp(),
    ),
  );
}

class WebViewApp extends StatefulWidget {
  const WebViewApp({super.key});

  @override
  State<WebViewApp> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewApp> {
  String? loginId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    getSessionID(loginId.toString());
    setState(() {});
  }

//login-challenge
  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      dataMain = jsonDecode(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = dataMain['sessionId'].toString();
      prefs.setString('sessionId', sessionId);
      return sessionId;
    }
    return '';
  }

//content access
  dynamic dataMains;
  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });

    if (response.statusCode == 201) {
      dataMains = jsonDecode(response.body);
      var responseString = response.body;

      // ignore: use_build_context_synchronously
      Navigator.pop(context, {"response": responseString});
    }
  }

  JavascriptChannel _javascriptChannel() {
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          if (message.message == 'loginSuccess') {
            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : const Padding(
            padding: EdgeInsets.all(8.0),
          );
  }

  @override
  Widget build(BuildContext context) {
    <JavascriptChannel>{_javascriptChannel()};

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  '${APIMode.SERVICE_BASE_URL}/overlay?clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
              javascriptMode: JavascriptMode.unrestricted,
              onProgress: (int progress) async {
                <JavascriptChannel>{_javascriptChannel()};
              },
              onWebViewCreated: (controller) {},
              navigationDelegate: (NavigationRequest request) {
                if (request.url.startsWith('https://xyz.zyz')) {
                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  Navigator.pop(context);
                }

                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {},
              onPageFinished: (String url) {},
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : const Center(child: CircularProgressIndicator()),
    );
  }
}
